
gaussiancl
==========

**angular power spectra transformation for Gaussian random fields**

This is a minimal Python package for working with the angular power spectra of
spherical random fields constructed from transformed Gaussian random fields.
It can currently transform power spectra of lognormal fields.

The package can be installed using pip:

    pip install gaussiancl

Then import the `lognormal_cl` and `lognormal_normal_cl` functions from the
package:

    from gaussiancl import lognormal_cl, lognormal_normal_cl

For more information, please see the [documentation].

Current functionality covers the absolutely minimal use case.  Please open an
issue on GitHub if you would like to see anything added.

[documentation]: https://cltools.readthedocs.io/gaussiancl/
